/*
**  fdamondf.h
**
**  Structures for ACTMONDB.FD (Activity Monitor Database)
**
**  Copyright 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                     FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __FDAMONDF_H__
#define __FDAMONDF_H__

#ifdef __cplusplus
extern "C" {
#endif

#define amHdrSignature   "FrontDoor Activity Monitor Database\r\n\x1a"
#define amHdrBinSig      0x3A4A5A6AL
#define amHdrVersion     0x00000100L
#define amRecBinSig      0x3C4C5C6CL

  /*Action flags*/
#define amFlgActive      0x00000001L                                /*Active*/
#define amFlgFrozen      0x00000002L                                /*Frozen*/
#define amFlgSession     0x00000004L                            /*In session*/
#define amFlgTerminal    0x00000008L                        /*Using Terminal*/
#define amFlgCalling     0x00000010L                               /*Calling*/
#define amFlgAnswering   0x00000020L                             /*Answering*/
#define amFlgRing        0x00000040L                  /*Have received "RING"*/
#define amFlgExitUser    0x00000080L                      /*Exit: User break*/
#define amFlgExitMail    0x00000100L                   /*Exit: Mail received*/
#define amFlgExitBBS     0x00000200L                      /*Exit: BBS caller*/
#define amFlgExitError   0x00000400L                           /*Exit: Error*/
#define amFlgExitOther   0x00000800L                 /*Exit: Semaphore, etc.*/
#define amFlgProcMail    0x00001000L                       /*Processing mail*/
#define amFlgWFC         0x00002000L                /*Waiting for call/event*/
#define amFlgPackHistory 0x00004000L                  /*Packing mail history*/
#define amFlgPackSTQ     0x00008000L                           /*Packing STQ*/
#define amFlgUser        0x00010000L                      /*User interaction*/
#define amFlgMailWaiting 0x00020000L                    /*Mail waiting is on*/
#define amFlgFaxWaiting  0x00040000L                     /*Fax waiting is on*/
#define amFlgUndialable  0x00080000L                     /*Undialables exist*/
#define amFlgFDServer    0x00100000L           /*Processing FDSERVER request*/

#define amFlgIsMultiLine 0x20000000L       /*MultiLine version of FD running*/
#define amFlgNotFD       0x40000000L              /*Something else is active*/
#define amFlgNotFDmsg    0x80000000L              /*There's something to say*/

  /*Flags1*/
#define amFlgNoCall      0x00000001L                   /*Not allowed to call*/
#define amFlgNoAnswer    0x00000002L                 /*Not allowed to answer*/
#define amFlgNoRescan    0x00000004L                 /*Not allowed to rescan*/
#define amFlgNoUser      0x00000008L                /*No interactive callers*/
#define amFlgNoExit      0x00000010L              /*No exits on inbound mail*/

  /*SessionFlags*/
#define amSFconnected    0x00000001L                        /*Session active*/
#define amSFRemNoFREQ    0x00000002L           /*Remote does not honor FREQs*/
#define amSFRemNoPU      0x00000004L            /*Remote does not want to PU*/
#define amSFOutbound     0x00000008L   /*Outbound session, otherwise inbound*/
#define amSFFTS1         0x08000000L                  /*sType: FTS1         */
#define amSFFTS6         0x10000000L                  /*sType: FTS6         */
#define amSFEMSI         0x20000000L                  /*sType: EMSI/EMSI-MD5*/
#define amSFFAX          0x40000000L                  /*sType: FAX          */
#define amSFOther        0x80000000L                  /*sType: Other        */

#define amMaxTasks       256
#define amTaskRecSize    8L                  /*sizeof(struct amFDActFastRec)*/
#define amTaskRecCount   amMaxTasks

typedef struct amFDActFRec
    {
    unsigned long       Counter;                      /*Last updated counter*/
    unsigned long       Action;                 /*Action, mirrored in record*/
    }
    amFDActFastRec;

typedef struct amFDActHRec
    {
    char                FingerPrint[39];                    /*amHdrSignature*/
    long                BinFingerPrint;                        /*amHdrBinSig*/
    long                Version;                              /*amHdrVersion*/
    long                TableRecSize;                        /*amTaskRecSize*/
    long                TableRecCount;                      /*amTaskRecCount*/
    long                RecSize;            /*sizeof(struct amFDActivityRec)*/
    char                RESERVED[1024];                           /*RESERVED*/
    }
    amFDActHdrRec;

  /*@ After amFDActHdrRec, NN (amTaskRecCount) amFDActFastRec records follow,
    @ and then each individual task's amFDActivityRec record.
    @
    @ Only the MultiLine version of FrontDoor is capable of using task slots
    @ other than the first (zero) slot.*/

typedef struct amFDActRec
    {
    long                BinFingerPrint;                        /*amRecBinSig*/
    unsigned long       TimeStamp;                            /*Last updated*/
    unsigned long       Flags1;                    /*Various mailer settings*/
    unsigned long       Flags2;                                   /*RESERVED*/
    unsigned long       ActionMirror;                     /*Current activity*/
    unsigned long       ActionDetail;                    /*Detailed activity*/
    unsigned long       Action3;                                  /*RESERVED*/
    char                Data[256];                          /*Printable data*/
    unsigned long       SessFlags;                /*Session-related flags   */
    unsigned long       SessStart;                /*Start of session        */
    unsigned long       SessOutFiles;             /*Number of files sent    */
    unsigned long       SessOutBytes;             /*Number of bytes sent    */
    unsigned long       SessInFiles;              /*Number of files received*/
    unsigned long       SessInBytes;              /*Number of bytes received*/
    char                SessRemName[65];          /*Remote's system name    */
    char                SessRemLocation[41];      /*Remote's location       */
    char                SessRemAddress[65];       /*Remote's primary address*/
    char                RESERVED[525];                            /*RESERVED*/
    char                AppIDstring[20];        /*Current application's name*/
    }
    amFDActivityRec;

  /* AppIDstring (above) is an ASCIIZ (NUL terminated) string and does
   * NOT have a length byte. In the case of FrontDoor, it will contain
   * "FrontDoor <version>", e.g. "FrontDoor 2.30.mL"<NUL>
   *
   * All other char[] fields are actually standard Pascal STRINGs with
   * a leading length byte. They are NOT NUL terminated.*/

#define amDetNone              0L
  
#define amDetProtReceiving     1002L
#define amDetProtReceivingFax  1003L
#define amDetProtSending       1004L
#define amDetProtSendingFax    1005L
#define amDetProcFileRequests  1006L

#define amDetExternalFax       2000L
#define amDetExternalFaxPrint  2001L
#define amDetProcOutboundMail  2002L
#define amDetProcReceivedMail  2003L
#define amDetPackingHistory    2004L
#define amDetPackingSTQ        2005L
#define amDetProcFDSERVER      2006L
#define amDetExit              2007L

#define amDetUserConsoleMgr    3000L
#define amDetUserTransmitF     3001L
#define amDetUserRequestF      3002L
#define amDetUserSTQ           3003L
#define amDetUserEditor        3004L
#define amDetUserConfigure     3005L
#define amDetUserShell         3006L
#define amDetUserFunctionKey   3007L
#define amDetUserMailHistory   3008L
#define amDetUserUndialable    3009L
#define amDetUserForcePollSTQ  3010L
#define amDetUserSTQChangeDest 3011L
#define amDetUserFDNC          3012L

#define amDetNotFDmsg          100000L /*'Data' contains msg from non-FD app*/

#ifdef __cplusplus
}
#endif
#endif /*__FDAMONDF_H__*/

/* end of file "fdamondf.inc" */

