{*
**  fdamondf.inc
**
**  Structures for ACTMONDB.FD (Activity Monitor Database)
**
**  Copyright 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                     FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*}

CONST
  amHdrSignature      ='FrontDoor Activity Monitor Database'#13#10#26#0;
  amHdrBinSig         =$3A4A5A6A;
  amHdrVersion        =$00000100;
  amRecBinSig         =$3C4C5C6C;

  {--Action flags--}
  amFlgActive         =$00000001;                                     {Active}
  amFlgFrozen         =$00000002;                                     {Frozen}
  amFlgSession        =$00000004;                                 {In session}
  amFlgTerminal       =$00000008;                             {Using Terminal}
  amFlgCalling        =$00000010;                                    {Calling}
  amFlgAnswering      =$00000020;                                  {Answering}
  amFlgRing           =$00000040;                       {Have received "RING"}
  amFlgExitUser       =$00000080;                           {Exit: User break}
  amFlgExitMail       =$00000100;                        {Exit: Mail received}
  amFlgExitBBS        =$00000200;                           {Exit: BBS caller}
  amFlgExitError      =$00000400;                                {Exit: Error}
  amFlgExitOther      =$00000800;                      {Exit: Semaphore, etc.}
  amFlgProcMail       =$00001000;                            {Processing mail}
  amFlgWFC            =$00002000;                     {Waiting for call/event}
  amFlgPackHistory    =$00004000;                       {Packing mail history}
  amFlgPackSTQ        =$00008000;                                {Packing STQ}
  amFlgUser           =$00010000;                           {User interaction}
  amFlgMailWaiting    =$00020000;                         {Mail waiting is on}
  amFlgFaxWaiting     =$00040000;                          {Fax waiting is on}
  amFlgUndialable     =$00080000;                          {Undialables exist}
  amFlgFDServer       =$00100000;                {Processing FDSERVER request}

  amFlgIsMultiLine    =$20000000;            {MultiLine version of FD running}
  amFlgNotFD          =$40000000;                   {Something else is active}
  amFlgNotFDmsg       =$80000000;                   {There's something to say}

  {--Flags1--}
  amFlgNoCall         =$00000001;                        {Not allowed to call}
  amFlgNoAnswer       =$00000002;                      {Not allowed to answer}
  amFlgNoRescan       =$00000004;                      {Not allowed to rescan}
  amFlgNoUser         =$00000008;                     {No interactive callers}
  amFlgNoExit         =$00000010;                   {No exits on inbound mail}

  {--SessionFlags--}
  amSFconnected       =$00000001;                             {Session active}
  amSFRemNoFREQ       =$00000002;                {Remote does not honor FREQs}
  amSFRemNoPU         =$00000004;                 {Remote does not want to PU}
  amSFOutbound        =$00000008;        {Outbound session, otherwise inbound}
  amSFFTS1            =$08000000;                       {sType: FTS1         }
  amSFFTS6            =$10000000;                       {sType: FTS6         }
  amSFEMSI            =$20000000;                       {sType: EMSI/EMSI-MD5}
  amSFFAX             =$40000000;                       {sType: FAX          }
  amSFOther           =$80000000;                       {sType: Other        }

  amMaxTasks          =256;
  amTaskRecSize       =8;                                  {sizeof(amFastRec)}
  amTaskRecCount      =amMaxTasks;

TYPE
  ActFastRecP         =^ActFastRec;
  ActFastRec          =RECORD
    Counter           :LONGINT;                         {Last updated counter}
    Action            :LONGINT;                   {Action, mirrored in record}
  END;

  ActMonHdrP          =^ActMonHdr;
  ActMonHdr           =RECORD
    FingerPrint       :ARRAY[1..39] OF CHAR;                  {amHdrSignature}
    BinFingerPrint    :LONGINT;                                  {amHdrBinSig}
    Version           :LONGINT;                                 {amHdrVersion}
    TableRecSize      :LONGINT;                                {amTaskRecSize}
    TableRecCount     :LONGINT;                               {amTaskRecCount}
    RecSize           :LONGINT;                            {sizeof(ActMonRec)}
    RESERVED          :ARRAY[1..1024] OF BYTE;                      {RESERVED}
  END;{ActMonHdr}

  {@ After ActMonHdr, NN (amTaskRecCount) ActFastRec records follow, and then
   @ each individual task's ActMonRec record.
   @
   @ Only the MultiLine version of FrontDoor is capable of using task slots
   @ other than the first (zero) slot.}

  ActMonRecP          =^ActMonRec;
  ActMonRec           =RECORD
    BinFingerPrint    :LONGINT;                                  {amRecBinSig}
    TimeStamp         :LONGINT;                                 {Last updated}
    Flags1            :LONGINT;                      {Various mailer settings}
    Flags2            :LONGINT;                                     {RESERVED}
    ActionMirror      :LONGINT;                             {Current activity}
    ActionDetail      :LONGINT;                            {Detailed activity}
    Action3           :LONGINT;                                     {RESERVED}
    Data              :STRING;                                {Printable data}
    SessFlags         :LONGINT;                     {Session-related flags   }
    SessStart         :LONGINT;                     {Start of session        }
    SessOutFiles      :LONGINT;                     {Number of files sent    }
    SessOutBytes      :LONGINT;                     {Number of bytes sent    }
    SessInFiles       :LONGINT;                     {Number of files received}
    SessInBytes       :LONGINT;                     {Number of bytes received}
    SessRemName       :STRING[64];                  {Remote's system name    }
    SessRemLocation   :STRING[40];                  {Remote's location       }
    SessRemAddress    :STRING[64];                  {Remote's primary address}
    RESERVED          :ARRAY[1..525] OF BYTE;
    AppIDstring       :ARRAY[1..20] OF CHAR;      {Current application's name}
  END;{ActMonRec}

  {@ AppIDstring (above) is an ASCIIZ (NUL terminated) string and does
   @ NOT have a length byte. In the case of FrontDoor, it will contain
   @ "FrontDoor <version>", e.g. "FrontDoor 2.30.mL"<NUL>
   @
   @ STRING fields are standard Pascal STRINGs with a leading length byte,
   @ making a total of 256 characters.
   @
   @ STRING[nn] fields are standard Pascal STRING[nn] fields with a leading
   @ length byte, making a total of nn+1 characters.}

CONST
  amDetNone             =0;
  
  amDetProtReceiving    =1002;
  amDetProtReceivingFax =1003;
  amDetProtSending      =1004;
  amDetProtSendingFax   =1005;
  amDetProcFileRequests =1006;

  amDetExternalFax      =2000;
  amDetExternalFaxPrint =2001;
  amDetProcOutboundMail =2002;
  amDetProcReceivedMail =2003;
  amDetPackingHistory   =2004;
  amDetPackingSTQ       =2005;
  amDetProcFDSERVER     =2006;
  amDetExit             =2007;

  amDetUserConsoleMgr   =3000;
  amDetUserTransmitF    =3001;
  amDetUserRequestF     =3002;
  amDetUserSTQ          =3003;
  amDetUserEditor       =3004;
  amDetUserConfigure    =3005;
  amDetUserShell        =3006;
  amDetUserFunctionKey  =3007;
  amDetUserMailHistory  =3008;
  amDetUserUndialable   =3009;
  amDetUserForcePollSTQ =3010;
  amDetUserSTQChangeDest=3011;
  amDetUserFDNC         =3012;

  amDetNotFDmsg         =100000;     {'Data' contains message from non-FD app}

{end of file "fdamondf.inc"}
