(*
**  fdmsg.inc
**
**  Structures for .MSG files
**
**  Copyright 1993-1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                          FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

(*
**  FTS-1 (Opus 1.03 compatible) message header definition used by FrontDoor,
**  and TosScan among other products to create .MSG files. "!!" indicates
**  that the bit is not used by FrontDoor.
*)
CONST
  MSGPRIVATE        =$0001;                                  {Private message}
  MSGCRASH          =$0002;                                    {High priority}
  MSGREAD           =$0004;                                {Read by addressee}
  MSGSENT           =$0008;                                    {Has been sent}
  MSGFILE           =$0010;                             {File attached to msg}
  MSGTRANSIT        =$0020;                                       {In transit}
  MSGORPHAN         =$0040;                                     {Unknown node}
  MSGKILL           =$0080;                               {Kill after mailing}
  MSGLOCAL          =$0100;                         {Message was entered here}
  MSGHOLD           =$0200;                                  {Hold for pickup}
  MSGUNUSED         =$0400;                                               {!!}
  MSGFREQ           =$0800;                                     {File request}
  MSGRRREQ          =$1000;                        {Return receipt request !!}
  MSGISRR           =$2000;        {Is return receipt - used for "Replied-to"}
  MSGAREQ           =$4000;                                 {Audit request !!}
  MSGFUPDREQ        =$8000;                           {File update request !!}

    {Message header, one per message}
    {All ARRAY fields are NUL terminated strings a'la C ASCIIZ strings.}

TYPE
  FIDOMSG           =RECORD
    FromUser        :ARRAY[1..36] OF CHAR;                 {Name in By: field}
    ToUser          :ARRAY[1..36] OF CHAR;                 {Name in To: field}
    Subject         :ARRAY[1..72] OF CHAR;                 {Name in Re: field}
    Date            :ARRAY[1..20] OF CHAR;      {Date ("dd Mmm yy  hh:mm:ss")}
    TimesRead       :WORD;                      {Number of times message read}
    DestNode        :WORD;                        {Destination node (0-65535)}
    OrigNode        :WORD;                        {Originating node (0-65535)}
    Cost            :WORD;           {Cost to send message, not used by FM/FD}
    OrigNet         :WORD;                         {Originating net (1-65535)}
    DestNet         :WORD;                         {Destination net (1-65535)}
    DateWritten     :LONGINT;                       {Date message was written}
    DateArrived     :LONGINT;                     {Date message was read/sent}
    ReplyTo         :WORD;                      {This is a reply to "ReplyTo"}
    Attr            :WORD;                         {Attribute bits, see above}
    ReplyNext       :WORD;                              {Next reply in thread}
  END;{FIDOMSG}

(*
**  The "DateWritten" and "DateArrived" fields are packed DOS dates with
**  the low word and high word exchanged as per the format used by Opus
**  1.03.
*)

(* end of file "fdmsg.inc" *)



