/*
**  fdpkt.h
**
**  Structures for .PKT (mail packet) files
**
**  Copyright 1993, 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                           FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __FDPKT_H__
#define __FDPKT_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  FTS-1 (FSC-39 compliant) packet definition used by FrontDoor, TosScan,
**  and FrontDoor APX among other products to create .PKT files.
*/
#define CW_2PLUS        0x0001                 /*Support for Type 2+ bundles*/
#define CW_N2PLUS       0x0100                     /*Validation for CW_2PLUS*/
#define PKTVERSION      2                    /*Current packet revision level*/

    /* Packet header, one per packet */

typedef struct _FDFTS1PktHdr
    {
    unsigned short int  OrigNode,                         /*Originating node*/
                        DestNode,                         /*Destination node*/
                        Year,                     /*Year created (1993-nnnn)*/
                        Month,                        /*Month created (0-11)*/
                        Day,                            /*Day created (1-31)*/
                        Hour,                          /*Hour created (0-23)*/
                        Minute,                      /*Minute created (0-59)*/
                        Second,                      /*Second created (0-59)*/
                        Rate,                            /*Baudrate (unused)*/
                        Version,                        /*Packet version (2)*/
                        OrigNet,                           /*Originating net*/
                        DestNet;                           /*Destination net*/
    unsigned char       PCodeLo,                  /*Product code (low-order)*/
                        PRevMajor;                           /*Major version*/
    char                Password[8];          /*Packet password (not ASCIIZ)*/
    unsigned short int  QMOrigZone,               /*Originating zone (QMail)*/
                        QMDestZone,               /*Destination zone (QMail)*/
                        AuxNet,                     /*Auxillary net (unused)*/
                        CWValidate;                     /*CapWord validation*/
    unsigned char       PCodeHi,                 /*Product code (high-order)*/
                        PRevMinor;                           /*Minor version*/
    unsigned short int  CWCapWord,                            /*Capabilities*/
                        OrigZone,                /*Originating zone (FSC-39)*/
                        DestZone,                /*Destination zone (FSC-39)*/
                        OrigPoint,              /*Originating point (FSC-39)*/
                        DestPoint;              /*Destination point (FSC-39)*/
    unsigned long       LongData;            /*Product dependent information*/
    }
    FDFTS1PktHdr;

    /* Packed message, none or more per packet */

typedef struct _FDFTS1PktMsg
    {
    unsigned short int  Version,                        /*Packet version (2)*/
                        OrigNode,                         /*Originating node*/
                        DestNode,                         /*Destination node*/
                        OrigNet,                           /*Originating net*/
                        DestNet,                           /*Destination net*/
                        Attr,                                  /*FTS1 status*/
                        Cost;                              /*Cost of message*/
    /*
    **    The message header follows this but is of variable length ASCIIZ
    **    strings in the order: AsciiDate, ToUser, FromUser, Subject, and
    **    MsgText.
    */
    }
    FDFTS1PktMsg;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "fdpkt.h" */

