(*
**  fdpkt.inc
**
**  Structures .PKT (mail packet) files
**
**  Copyright 1993, 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                           FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

(*
**  FTS-1 (FSC-39 compliant) packet definition used by FrontDoor, TosScan,
**  and FrontDoor APX among other products to create .PKT files.
*)
CONST
  CW_2PLUS              =$0001;                  {Support for Type 2+ bundles}
  CW_N2PLUS             =$0100;                      {Validation for CW_2PLUS}
  PKTVERSION            =2;                    {Current packet revision level}

  { Packet header, one per packet }

TYPE
  FTS1PKTHDR = RECORD
    OrigNode,                                               {Originating node}
    DestNode,                                               {Destination node}
    Year,                                           {Year created (1993-nnnn)}
    Month,                                              {Month created (0-11)}
    Day,                                                  {Day created (1-31)}
    Hour,                                                {Hour created (0-23)}
    Minute,                                            {Minute created (0-59)}
    Second,                                            {Second created (0-59)}
    Rate,                                                  {Baudrate (unused)}
    Version,                                              {Packet version (2)}
    OrigNet,                                                 {Originating net}
    DestNet  :WORD;                                           {Destination net}
    PCodeLo,                                        {Product code (low-order)}
    PRevMajor:BYTE;                                            {Major version}
    Password:ARRAY[1..8] of CHAR;               {Packet password (not ASCIIZ)}
    QMOrigZone,                                     {Originating zone (QMail)}
    QMDestZone,                                     {Destination zone (QMail)}
    AuxNet,                                           {Auxillary net (unused)}
    CWValidate:WORD;                                      {CapWord validation}
    PCodeHi,                                       {Product code (high-order)}
    PRevMinor:BYTE;                                            {Minor version}
    CWCapWord,                                                  {Capabilities}
    OrigZone,                                      {Originating zone (FSC-39)}
    DestZone,                                      {Destination zone (FSC-39)}
    OrigPoint,                                    {Originating point (FSC-39)}
    DestPoint:WORD;                               {Destination point (FSC-39)}
    LongData:LONGINT;                          {Product dependent information}
  END;{FTS1PKTHDR}

  { Packed message, none or more per packet }

  FTS1PKTMSG = RECORD
    Version,                                              {Packet version (2)}
    OrigNode,                                               {Originating node}
    DestNode,                                               {Destination node}
    OrigNet,                                                 {Originating net}
    DestNet,                                                 {Destination net}
    Attr,                                                        {FTS1 status}
    Cost    :WORD;                                           {Cost of message}
    (*
    **  The message header follows this but is of variable length ASCIIZ
    **  strings in the order: AsciiDate, ToUser, FromUser, Subject, and
    **  MsgText.
    *)
  END;{FTS1PKTMSG}

(* end of file "fdpkt.inc" *)

