/*
**  fdstq.h
**
**  Structures for FILQUEUE.FD (FrontDoor Static Queue [STQ] Database)
**
**  Copyright 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                     FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __FDSTQ_H__
#define __FDSTQ_H__

#ifdef __cplusplus
extern "C" {
#endif

#define FQflgKFS         0x00000001L   /*Kill file after sending, w/checking*/
#define FQflgKFSNoCheck  0x00000002L            /*Like KFS, but w/o checking*/
#define FQflgTFS         0x00000004L   /*Trunc file after sending w/checking*/
#define FQflgTFSNoCheck  0x00000008L            /*Like TFS, but w/o checking*/
#define FQflgIsARCmail   0x00000020L                        /*ARCmail attach*/
#define FQflgSendStart   0x00000040L      /*FD has started to send this file*/
#define FQflgSendAfter   0x00020000L      /*Date contains entry release date*/
#define FQflgKeepExpired 0x00040000L                    /*Keep expired entry*/
#define FQflgSendUntil   0x00080000L   /*Date contains entry expiration date*/
#define FQflgIsHold      0x00100000L                                  /*Hold*/
#define FQflgIsCrash     0x00200000L                                 /*Crash*/
#define FQflgIsIMM       0x00400000L                             /*Immediate*/
#define FQflgNoPickup    0x00800000L                     /*Must be delivered*/
#define FQflgIsSpool     0x01000000L   /*Spool mask (Permanent + KFSNoCheck)*/
#define FQflgIsFREQ      0x02000000L                       /*Is file request*/
#define FQflgIsFile      0x04000000L                        /*Is file attach*/
#define FQflgTFA         0x08000000L     /*TFA field contains alias filename*/
#define FQflgHidden      0x20000000L           /*Hidden entry, don't display*/
#define FQflgLocked      0x40000000L                  /*Locked entry, ignore*/
#define FQflgDeleted     0x80000000L                /*Entry has been deleted*/
#define FQflgPassword    0x08000000L                /*Used for File Requests*/
#define FQmacHasFilename (FQflgIsFREQ | FQflgIsFile)

#define FileQLockFN      "FILQUEUE.LCK"
#define FileQSignature   "FrontDoor File Queue\x1a"              /*Signature*/
#define FileQRevision    0x0100                        /*File queue revision*/

typedef struct fdSTQBinHdr                                   /*Header record*/
    {
    char                Signature[22];                      /*FileQSignature*/
    unsigned short int  Revision;                            /*FileQRevision*/
    unsigned long       TimeCreated;             /*Creation time, UNIX-style*/
    unsigned long       TimePacked;           /*Last time packed, UNIX-style*/
    unsigned long       ReservedLong;                             /*RESERVED*/
    unsigned long       PackRecovery;               /*0 if clear, 0xffffffff*/
    }                                               /*..during TMP->STQ copy*/
    fdSTQBinHdrRec;

typedef struct fdSTQFileHdr
    {
    fdSTQBinHdrRec      Hdr;                          /*Actual header record*/
    char                RESERVED[1024-sizeof(fdSTQBinHdrRec)];    /*RESERVED*/
    }
    fdSTQFileHdrRec;

  /* Each record is variable size with a fixed-sized header. EntryLen
   * contains the amount of data following the EntryLen field (EntryLen
   * excluded).
   *
   * Note that all "string" fields in the STQ are Pascal-style strings with
   * a leading length-byte, followed by zero or more bytes.*/

typedef struct fdSTQEntry
    {
    unsigned short int  EntryLen; /*Length of data following, excl. EntryLen*/
    unsigned long       EntryTime;         /*Time added to queue, UNIX-style*/
    unsigned long       Flags;                  /*Flags, see above FQflgXXXX*/
    unsigned long       TimeStamp;/*For ..SendUntil & ..SendAfter, UNIX-style*/
    /*char Address[]*/
    /*char Filename[]*/
    /*char TFA[]*/
    }
    fdSTQEntryRec;

#ifdef __cplusplus
}
#endif
#endif /*__FDSTQ_H__*/

/* end of file "fdstq.h" */
