{*
**  fdstq.inc
**
**  Structures for FILQUEUE.FD (FrontDoor Static Queue [STQ] Database)
**
**  Copyright 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                     FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*}

CONST
  FQflgKFS        =$00000001;            {Kill file after sending, w/checking}
  FQflgKFSNoCheck =$00000002;                     {Like KFS, but w/o checking}
  FQflgTFS        =$00000004;            {Trunc file after sending w/checking}
  FQflgTFSNoCheck =$00000008;                     {Like TFS, but w/o checking}
  FQflgIsARCmail  =$00000020;                                 {ARCmail attach}
  FQflgSendStart  =$00000040;               {FD has started to send this file}
  FQflgSendAfter  =$00020000;               {Date contains entry release date}
  FQflgKeepExpired=$00040000;                             {Keep expired entry}
  FQflgSendUntil  =$00080000;            {Date contains entry expiration date}
  FQflgIsHold     =$00100000;                                           {Hold}
  FQflgIsCrash    =$00200000;                                          {Crash}
  FQflgIsIMM      =$00400000;                                      {Immediate}
  FQflgNoPickup   =$00800000;                              {Must be delivered}
  FQflgIsSpool    =$01000000;            {Spool mask (Permanent + KFSNoCheck)}
  FQflgIsFREQ     =$02000000;                                {Is file request}
  FQflgIsFile     =$04000000;                                 {Is file attach}
  FQflgTFA        =$08000000;              {TFA field contains alias filename}
  FQflgHidden     =$20000000;                    {Hidden entry, don't display}
  FQflgLocked     =$40000000;                           {Locked entry, ignore}
  FQflgDeleted    =$80000000;                         {Entry has been deleted}
  FQflgPassword   =$08000000;                         {Used for File Requests}
  FQmacHasFilename=(FQflgIsFREQ or FQflgIsFile);

  FileQLockFN     ='FILQUEUE.LCK';
  FileQSignature  ='FrontDoor File Queue'#26#0;     {Signature of FILQUEUE.FD}
  FileQRevision   =$0100;                                {File queue revision}

TYPE
  FileQBinHdr     =RECORD                                      {Header record}
    Signature     :ARRAY[1..22] OF CHAR;                      {FileQSignature}
    Revision      :WORD;                                       {FileQRevision}
    TimeCreated   :LONGINT;                        {Creation time, UNIX-style}
    TimePacked    :LONGINT;                     {Last time packed, UNIX-style}
    ReservedLong  :LONGINT;                                         {RESERVED}
    PackRecovery  :LONGINT;      {0 if clear, 0xffffffff during TMP->STQ copy}
  END;{FileQBinHdr}

  FileQHdr        =RECORD                                      {Header record}
    Hdr           :FileQBinHdr;                         {Actual header record}
    RESERVED      :ARRAY[1..1024-sizeof(FileQBinHdr)] OF CHAR;      {RESERVED}
  END;

  {-Each record is variable size with a fixed-sized header. EntryLen contains
    the amount of data following the EntryLen field (EntryLen excluded).}

  FileQRecPtr     =^FileQRec;
  FileQRec        =RECORD
    EntryLen      :WORD;        {Length of data following, excluding EntryLen}
    EntryTime     :LONGINT;                  {Time added to queue, UNIX-style}
    Flags         :LONGINT;                       {Flags, see above FQflgXXXX}
    TimeStamp     :LONGINT;      {For ..SendUntil and ..SendAfter, UNIX-style}
    {..Address..}
    {..Filename..}
    {..TFA..}
  END;{FileQRec}

{end of file "fdstq.inc"}

