/*
**  folder.h
**
**  Structures for FOLDER.FD
**
**  Copyright 1991-1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                          FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __FOLDER_H__
#define __FOLDER_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  PATH and TITLE are NUL terminated, a'la C ASCIIZ strings.
*/
typedef struct _ctlFDFolder
    {
    char            MsgPath[65];      /*Path if not HMB/JAM, otherwise emtpy*/
    char            Title[41];                   /*Title to appear on screen*/
    unsigned char   OriginNum;                   /*Default origin line, 0-19*/
    long            Flags;                                /*Flags, see below*/
    long            PwdCRC;        /*CRC32 of password or -1L if unprotected*/
    long            UserMask;         /*Users with initial access, see below*/
    unsigned char   UseAKANum;                       /*AKA to use, 0=Primary*/
    unsigned short int
                    BoardNum;                             /*HMB board number*/
    }
    ctlFDFolder, *ctlFDFolderPtr;

/*
**  Constant long bit values
*/
#define FOLDER_RESTRICT     0x00000001L                  /*Restricted folder*/
#define FOLDER_ECHOINFO     0x00000002L            /*Add Origin: information*/
#define FOLDER_EXPORTOK     0x00000004L  /*OK for user to export from folder*/
#define FOLDER_USEXLAT      0x00000008L             /*Use translation tables*/
#define FOLDER_PRIVATE      0x00000010L         /*Add Private message status*/
#define FOLDER_READONLY     0x00000020L                /*Folder is read-only*/
#define FOLDER_FORCEHARDCR  0x00000040L    /*Force hard CRs at linebreak (C)*/
#define FOLDER_NEWSGROUP    0x00000080L /*Special treatment of some msg data*/
#define FOLDER_REPLYTONMF   0x00000100L /*'R'eply key goes to NetMail Folder*/
#define FOLDER_SEPARATOR    0x00000200L                          /*Separator*/
#define FOLDER_LOCKORIG     0x00000400L/*Do not allow origin to be selected/
                                                                      chosen*/
#define FOLDER_NEWIFANY     0x00800000L    /*"new" indicator if ANY messages*/
#define FOLDER_JAM          0x01000000L            /*JAM message base folder*/
#define FOLDER_NOCHECK      0x02000000L    /*Exclude from new mail check (C)*/
#define FOLDER_NETMAIL      0x08000000L            /*Netmail-type folder (C)*/
#define FOLDER_HMB          0x10000000L         /*Hudson Message Base folder*/
#define FOLDER_DELETED      0x20000000L              /*Never written to disk*/
#define FOLDER_LOCAL        0x40000000L                  /*Local-type folder*/
#define FOLDER_ECHOMAIL     0x80000000L             /*Conference-type folder*/

/*
**  User access mask
*/
#define FOLDER_USER_1       0x00000001L
#define FOLDER_USER_2       0x00000002L
#define FOLDER_USER_3       0x00000004L
#define FOLDER_USER_4       0x00000008L
#define FOLDER_USER_5       0x00000010L
#define FOLDER_USER_6       0x00000020L
#define FOLDER_USER_7       0x00000040L
#define FOLDER_USER_8       0x00000080L
#define FOLDER_USER_9       0x00000100L
#define FOLDER_USER_10      0x00000200L

#ifdef __cplusplus
}
#endif
#endif

/* end of file "folder.h" */
