/*
**  linecfg.h
**
**  Structure for MDCFG<TaskNum>.FD
**
**  Copyright 1993-1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                          FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __LINECFG_H__
#define __LINECFG_H__

#ifdef __cplusplus
extern "C" {
#endif

#define LINECFG_REV             0x0102                       /*Used by 2.25+*/
#define OLDLINECFG_REV          0x0101             /*Used by 2.20b and 2.20c*/
#define OLDESTLINECFG_REV       0x0100              /*Used by 2.20 and 2.20a*/

/*
**    Modem flags
*/
#define MODEMCFG_DTR_HANGUP     0x00000001L              /*Use DTR to hangup*/
#define MODEMCFG_DTR_DIAL       0x00000002L    /*Toggle DTR prior to dialing*/
#define MODEMCFG_DTR_BUSY       0x00000004L         /*Use DTR to signal BUSY*/
#define MODEMCFG_MANUAL_ANSWER  0x00000008L              /*Use manual answer*/
#define MODEMCFG_CONNECT_RESET  0x00000010L   /*Reset modem to connect speed*/
#define MODEMCFG_FIXED          0x00000020L             /*Constant DTE speed*/
#define MODEMCFG_NULLMODEM      0x00000040L  /*Initiate session when CD high*/
#define MODEMCFG_FAXAUTORECEIVE 0x00000080L       /*Handle inbound fax calls*/
#define MODEMCFG_MAILERLOGDFRS  0x00000100L /*Log data following RING signal*/
#define MODEMCFG_NODIALISBUSY   0x00000200L/*Don't treat NO DIALTONE as RING*/
#define MODEMCFG_RINGINITOK     0x00000400L   /*RING is OK when initializing*/
#define MODEMCFG_ANSWERCOUNT    0x00000800L/*Manual answer, on specific RING*/

typedef struct ctlFDModemCFG
    {
    unsigned long       Flags;                        /*Modem specific flags*/
    unsigned short int  Baudrate;                    /*30=300, 24=2400, etc.*/
    unsigned char       COMport;              /*1-255 (COM1=1, COM2=2, etc.)*/
    unsigned char       LineDelay;          /*1/10 seconds delay / line sent*/
    unsigned char       CDMASK;

    /* Connect messages */

    struct
        {
        char            Message[16];                       /*CONNECT message*/
        unsigned long   Baudrate;                   /*Corresponding baudrate*/
        }
        ConMsg[5];
    char                ConnectPrefix[16];               /*Usually "CONNECT"*/
    unsigned long       RESERVEDlong1;                            /*RESERVED*/
    unsigned long       RESERVEDlong2;                            /*RESERVED*/
    unsigned long       RESERVEDlong3;                            /*RESERVED*/
    char                ModemAnswer2[41];
    char                RESERVEDchar[7];                          /*RESERVED*/
    char                b21600msg[16];                      /*!!!NOT USED!!!*/
    char                b24000msg[16];                      /*!!!NOT USED!!!*/
    char                b26400msg[16];                      /*!!!NOT USED!!!*/
    char                b28800msg[16];                      /*!!!NOT USED!!!*/
    char                b38400Msg[16];                      /*!!!NOT USED!!!*/
    char                b57600Msg[16];                      /*!!!NOT USED!!!*/
    char                b64000Msg[16];                      /*!!!NOT USED!!!*/
    char                b115200Msg[16];                     /*!!!NOT USED!!!*/
    char                b31200Msg[16];                      /*!!!NOT USED!!!*/
    char                b33600Msg[16];                      /*!!!NOT USED!!!*/
    char                ModemCustomMsg[16];                 /*!!!NOT USED!!!*/
    long                ModemCustomBaud;                    /*!!!NOT USED!!!*/
    char                bfaxMsg[16];
    char                errorMsg[16];
    char                busyMsg[16];
    char                carrierMsg[16];
    char                okMsg[16];
    char                ringMsg[16];
    char                nodialMsg[16];
    char                noanswMsg[16];
    char                voiceMsg[16];

    /* Command strings */

    char                modemanswer[41];
    unsigned char       AnswerDelay;

    char                escapestr[11];
    char                offhookstr[11];
    char                reconnectstr[11];
    char                init1[50];
    char                init2[50];
    char                init3[50];
    char                resetstr[50];
    char                downstr[50];
    char                hangupstr[11];
    char                dialstr[11];
    char                prefix[31];                           /*Always added*/
    char                postfix[31];                       /*Always appended*/
    char                mTermInit[19];  /*Task specific Terminal init string*/
    unsigned char       RingingCount;       /*Number of RINGING before abort*/
    }
    MODEMCFG;

typedef struct ctlFDLineCFG
    {
    char    Fingerprint[5];                       /*Must contain "JoHo<NUL>"*/
    unsigned short int
            FileRevision;                                      /*LINECFG_REV*/
    unsigned long
            CRC1;                  /*CRC32 of LINECFG excluding 1st 11 bytes*/
    MODEMCFG
            Modem;
    unsigned long
            CRC2;                                  /*CRC-32 of all the above*/
    }
    LINECFG;

/*--------------------------------------------------------------------------*/

typedef struct ctlFDOldModemCFG
    {
    unsigned long       Flags;                        /*Modem specific flags*/
    unsigned short int  Baudrate;                    /*30=300, 24=2400, etc.*/
    unsigned char       COMport;              /*1-255 (COM1=1, COM2=2, etc.)*/
    unsigned char       LineDelay;          /*1/10 seconds delay / line sent*/
    unsigned char       CDMASK;

    /* Connect messages */

    char    b300Msg[16];
    char    b1200Msg[16];
    char    b1275Msg[16];
    char    b2400Msg[16];
    char    b4800Msg[16];
    char    b7200Msg[16];
    char    b9600Msg[16];
    char    b12000Msg[16];
    char    b14400Msg[16];
    char    b16800Msg[16];
    char    b19200Msg[16];
    char    b21600msg[16];
    char    b24000msg[16];
    char    b26400msg[16];
    char    b28800msg[16];
    char    b38400Msg[16];
    char    b57600Msg[16];
    char    b64000Msg[16];
    char    b115200Msg[16];
    char    b31200Msg[16];
    char    b33600Msg[16];
    char    ModemCustomMsg[16];
    long    ModemCustomBaud;
    char    bfaxMsg[16];
    char    errorMsg[16];
    char    busyMsg[16];
    char    carrierMsg[16];
    char    okMsg[16];
    char    ringMsg[16];
    char    nodialMsg[16];
    char    noanswMsg[16];
    char    voiceMsg[16];

    /* Command strings */

    char    modemanswer[41];
    unsigned char
            AnswerDelay;

    char    escapestr[11];
    char    offhookstr[11];
    char    reconnectstr[11];
    char    init1[50];
    char    init2[50];
    char    init3[50];
    char    resetstr[50];
    char    downstr[50];
    char    hangupstr[11];
    char    dialstr[11];
    char    prefix[31];                                       /*Always added*/
    char    postfix[31];                                   /*Always appended*/
    char    mTermInit[19];              /*Task specific Terminal init string*/
    unsigned char
            RingingCount;                   /*Number of RINGING before abort*/
    }
    OLDMODEMCFG;

typedef struct ctlFDOldLineCFG
    {
    char    Fingerprint[5];                       /*Must contain "JoHo<NUL>"*/
    unsigned short int
            FileRevision;                                   /*OLDLINECFG_REV*/
    unsigned long
            CRC1;                  /*CRC32 of LINECFG excluding 1st 11 bytes*/
    OLDMODEMCFG
            Modem;
    unsigned long
            CRC2;                                  /*CRC-32 of all the above*/
    }
    OLDLINECFG;

/*--------------------------------------------------------------------------*/

typedef struct ctlFDOldestModemCFG
    {
    unsigned long       Flags;                        /*Modem specific flags*/
    unsigned short int  Baudrate;                    /*30=300, 24=2400, etc.*/
    unsigned char       COMport;              /*1-255 (COM1=1, COM2=2, etc.)*/
    unsigned char       LineDelay;          /*1/10 seconds delay / line sent*/
    unsigned char       CDMASK;

    /* Connect messages */

    char    b300Msg[16];
    char    b1200Msg[16];
    char    b1275Msg[16];
    char    b2400Msg[16];
    char    b4800Msg[16];
    char    b7200Msg[16];
    char    b9600Msg[16];
    char    b12000Msg[16];
    char    b14400Msg[16];
    char    b16800Msg[16];
    char    b19200Msg[16];
    char    b38400Msg[16];
    char    b57600Msg[16];
    char    b64000Msg[16];
    char    b115200Msg[16];
    char    ModemCustomMsg[16];
    long    ModemCustomBaud;
    char    bfaxMsg[16];
    char    errorMsg[16];
    char    busyMsg[16];
    char    carrierMsg[16];
    char    okMsg[16];
    char    ringMsg[16];
    char    nodialMsg[16];
    char    noanswMsg[16];
    char    voiceMsg[16];

    /* Command strings */

    char    modemanswer[41];
    unsigned char
            AnswerDelay;

    char    escapestr[11];
    char    offhookstr[11];
    char    reconnectstr[11];
    char    init1[50];
    char    init2[50];
    char    init3[50];
    char    resetstr[50];
    char    downstr[50];
    char    hangupstr[11];
    char    dialstr[11];
    char    prefix[31];                                       /*Always added*/
    char    postfix[31];                                   /*Always appended*/
    }
    OLDESTMODEMCFG;

typedef struct ctlFDOldestLineCFG
    {
    char    Fingerprint[5];                       /*Must contain "JoHo<NUL>"*/
    unsigned short int
            FileRevision;                                /*OLDESTLINECFG_REV*/
    unsigned long
            CRC1;                  /*CRC32 of LINECFG excluding 1st 11 bytes*/
    OLDESTMODEMCFG
            Modem;
    unsigned long
            CRC2;                                  /*CRC-32 of all the above*/
    }
    OLDESTLINECFG;


#ifdef __cplusplus
}
#endif
#endif

/* end of file "linecfg.h"*/
