{*
**  linecfg.h
**
**  Structure for MDCFG<TaskNum>.FD
**
**  Copyright 1993-1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                          FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*}

CONST
  LINECFG_REV             =$0102;                              {Used by 2.25+}
  OLDLINECFG_REV          =$0101;                    {Used by 2.20b and 2.20c}
  OLDESTLINECFG_REV       =$0100;                     {Used by 2.20 and 2.20a}

  {--Modem flags--}

  MODEMCFG_DTR_HANGUP     =$00000001;                      {Use DTR to hangup}
  MODEMCFG_DTR_DIAL       =$00000002;            {Toggle DTR prior to dialing}
  MODEMCFG_DTR_BUSY       =$00000004;                 {Use DTR to signal BUSY}
  MODEMCFG_MANUAL_ANSWER  =$00000008;                      {Use manual answer}
  MODEMCFG_CONNECT_RESET  =$00000010;           {Reset modem to connect speed}
  MODEMCFG_FIXED          =$00000020;                     {Constant DTE speed}
  MODEMCFG_NULLMODEM      =$00000040;          {Initiate session when CD high}
  MODEMCFG_FAXAUTORECEIVE =$00000080;               {Handle inbound fax calls}
  MODEMCFG_MAILERLOGDFRS  =$00000100;         {Log data following RING signal}
  MODEMCFG_NODIALISBUSY   =$00000200;        {Don't treat NO DIALTONE as RING}
  MODEMCFG_RINGINITOK     =$00000400;           {RING is OK when initializing}
  MODEMCFG_ANSWERCOUNT    =$00000800;        {Manual answer, on specific RING}

TYPE
  MODEMCFG                =RECORD
    Flags                 :LONGINT;                     {Modem specific flags}
    Baudrate              :WORD;                       {30=300, 24=2400, etc.}
    COMport               :BYTE;                {1-255 (COM1=1, COM2=2, etc.)}
    LineDelay             :BYTE;              {1/10 seconds delay / line sent}
    CDMASK                :BYTE;

    {Connect messages}

    ConMsg                :ARRAY[1..5] OF RECORD
      Message             :ARRAY[1..16] OF CHAR;             {CONNECT message}
      Baudrate            :LONGINT;                   {Corresponding baudrate}
    END;{ConMsg}

    ConnectPrefix         :ARRAY[1..16] OF CHAR;           {Usually "CONNECT"}
    RESERVEDlong1         :LONGINT;                                 {RESERVED}
    RESERVEDlong2         :LONGINT;                                 {RESERVED}
    RESERVEDlong3         :LONGINT;                                 {RESERVED}

    ModemAnswer2          :ARRAY[1..41] OF CHAR;
    RESERVEDchar          :ARRAY[1..7] OF CHAR;                     {RESERVED}

    b21600msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b24000msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b26400msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b28800msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b38400Msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b57600Msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b64000Msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b115200Msg            :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b31200Msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    b33600Msg             :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    ModemCustomMsg        :ARRAY[1..16] OF CHAR;              {!!!NOT USED!!!}
    ModemCustomBaud       :LONGINT;                           {!!!NOT USED!!!}
    bfaxMsg               :ARRAY[1..16] OF CHAR;
    errorMsg              :ARRAY[1..16] OF CHAR;
    busyMsg               :ARRAY[1..16] OF CHAR;
    carrierMsg            :ARRAY[1..16] OF CHAR;
    okMsg                 :ARRAY[1..16] OF CHAR;
    ringMsg               :ARRAY[1..16] OF CHAR;
    nodialMsg             :ARRAY[1..16] OF CHAR;
    noanswMsg             :ARRAY[1..16] OF CHAR;
    voiceMsg              :ARRAY[1..16] OF CHAR;

    {Command strings}

    ModemAnswer           :ARRAY[1..41] OF CHAR;
    AnswerDelay           :BYTE;
    EscapeStr             :ARRAY[1..11] OF CHAR;
    OffHookStr            :ARRAY[1..11] OF CHAR;
    ReconnectStr          :ARRAY[1..11] OF CHAR;
    Init1                 :ARRAY[1..50] OF CHAR;
    Init2                 :ARRAY[1..50] OF CHAR;
    Init3                 :ARRAY[1..50] OF CHAR;
    Resetstr              :ARRAY[1..50] OF CHAR;
    Downstr               :ARRAY[1..50] OF CHAR;
    HangupStr             :ARRAY[1..11] OF CHAR;
    DialStr               :ARRAY[1..11] OF CHAR;
    Prefix                :ARRAY[1..31] OF CHAR;                {Always added}
    Postfix               :ARRAY[1..31] OF CHAR;             {Always appended}
    mTermInit             :ARRAY[1..19] OF CHAR; {Task specific Terminal init}
    RingingCount          :BYTE;              {Number of RINGING before abort}
  END;{MODEMCFG}

  LINECFG                 =RECORD
    Fingerprint           :ARRAY[1..5] OF CHAR;     {Must contain "JoHo<NUL>"}
    FileRevision          :WORD;                                 {LINECFG_REV}
    CRC1                  :LONGINT;  {CRC32 of LINECFG excluding 1st 11 bytes}
    Modem                 :MODEMCFG;
    CRC2                  :LONGINT;                  {CRC-32 of all the above}
  END;{LINECFG}

{----------------------------------------------------------------------------}

  OLDMODEMCFG             =RECORD
    Flags                 :LONGINT;                     {Modem specific flags}
    Baudrate              :WORD;                       {30=300, 24=2400, etc.}
    COMport               :BYTE;                {1-255 (COM1=1, COM2=2, etc.)}
    LineDelay             :BYTE;              {1/10 seconds delay / line sent}
    CDMASK                :BYTE;

    b300Msg               :ARRAY[1..16] OF CHAR;
    b1200Msg              :ARRAY[1..16] OF CHAR;
    b1275Msg              :ARRAY[1..16] OF CHAR;
    b2400Msg              :ARRAY[1..16] OF CHAR;
    b4800Msg              :ARRAY[1..16] OF CHAR;
    b7200Msg              :ARRAY[1..16] OF CHAR;
    b9600Msg              :ARRAY[1..16] OF CHAR;
    b12000Msg             :ARRAY[1..16] OF CHAR;
    b14400Msg             :ARRAY[1..16] OF CHAR;
    b16800Msg             :ARRAY[1..16] OF CHAR;
    b19200Msg             :ARRAY[1..16] OF CHAR;
    b21600msg             :ARRAY[1..16] OF CHAR;
    b24000msg             :ARRAY[1..16] OF CHAR;
    b26400msg             :ARRAY[1..16] OF CHAR;
    b28800msg             :ARRAY[1..16] OF CHAR;
    b38400Msg             :ARRAY[1..16] OF CHAR;
    b57600Msg             :ARRAY[1..16] OF CHAR;
    b64000Msg             :ARRAY[1..16] OF CHAR;
    b115200Msg            :ARRAY[1..16] OF CHAR;
    b31200Msg             :ARRAY[1..16] OF CHAR;
    b33600Msg             :ARRAY[1..16] OF CHAR;
    ModemCustomMsg        :ARRAY[1..16] OF CHAR;
    ModemCustomBaud       :LONGINT;             
    bfaxMsg               :ARRAY[1..16] OF CHAR;
    errorMsg              :ARRAY[1..16] OF CHAR;
    busyMsg               :ARRAY[1..16] OF CHAR;
    carrierMsg            :ARRAY[1..16] OF CHAR;
    okMsg                 :ARRAY[1..16] OF CHAR;
    ringMsg               :ARRAY[1..16] OF CHAR;
    nodialMsg             :ARRAY[1..16] OF CHAR;
    noanswMsg             :ARRAY[1..16] OF CHAR;
    voiceMsg              :ARRAY[1..16] OF CHAR;

    {Command strings}

    ModemAnswer           :ARRAY[1..41] OF CHAR;
    AnswerDelay           :BYTE;
    EscapeStr             :ARRAY[1..11] OF CHAR;
    OffHookStr            :ARRAY[1..11] OF CHAR;
    ReconnectStr          :ARRAY[1..11] OF CHAR;
    Init1                 :ARRAY[1..50] OF CHAR;
    Init2                 :ARRAY[1..50] OF CHAR;
    Init3                 :ARRAY[1..50] OF CHAR;
    Resetstr              :ARRAY[1..50] OF CHAR;
    Downstr               :ARRAY[1..50] OF CHAR;
    HangupStr             :ARRAY[1..11] OF CHAR;
    DialStr               :ARRAY[1..11] OF CHAR;
    Prefix                :ARRAY[1..31] OF CHAR;                {Always added}
    Postfix               :ARRAY[1..31] OF CHAR;             {Always appended}
    mTermInit             :ARRAY[1..19] OF CHAR; {Task specific Terminal init}
    RingingCount          :BYTE;              {Number of RINGING before abort}
  END;{OLDMODEMCFG}

  OLDLINECFG              =RECORD
    Fingerprint           :ARRAY[1..5] OF CHAR;     {Must contain "JoHo<NUL>"}
    FileRevision          :WORD;                              {OLDLINECFG_REV}
    CRC1                  :LONGINT;  {CRC32 of LINECFG excluding 1st 11 bytes}
    Modem                 :OLDMODEMCFG;
    CRC2                  :LONGINT;                  {CRC-32 of all the above}
  END;{OLDLINECFG}

{----------------------------------------------------------------------------}

  OLDESTMODEMCFG          =RECORD
    Flags                 :LONGINT;                     {Modem specific flags}
    Baudrate              :WORD;                       {30=300, 24=2400, etc.}
    COMport               :BYTE;                {1-255 (COM1=1, COM2=2, etc.)}
    LineDelay             :BYTE;              {1/10 seconds delay / line sent}
    CDMASK                :BYTE;

    {Connect messages}

    b300Msg               :ARRAY[1..16] OF CHAR;
    b1200Msg              :ARRAY[1..16] OF CHAR;
    b1275Msg              :ARRAY[1..16] OF CHAR;
    b2400Msg              :ARRAY[1..16] OF CHAR;
    b4800Msg              :ARRAY[1..16] OF CHAR;
    b7200Msg              :ARRAY[1..16] OF CHAR;
    b9600Msg              :ARRAY[1..16] OF CHAR;
    b12000Msg             :ARRAY[1..16] OF CHAR;
    b14400Msg             :ARRAY[1..16] OF CHAR;
    b16800Msg             :ARRAY[1..16] OF CHAR;
    b19200Msg             :ARRAY[1..16] OF CHAR;
    b38400Msg             :ARRAY[1..16] OF CHAR;
    b57600Msg             :ARRAY[1..16] OF CHAR;
    b64000Msg             :ARRAY[1..16] OF CHAR;
    b115200Msg            :ARRAY[1..16] OF CHAR;

    ModemCustomMsg        :ARRAY[1..16] OF CHAR;
    ModemCustomBaud       :LONGINT;             
    bfaxMsg               :ARRAY[1..16] OF CHAR;
    errorMsg              :ARRAY[1..16] OF CHAR;
    busyMsg               :ARRAY[1..16] OF CHAR;
    carrierMsg            :ARRAY[1..16] OF CHAR;
    okMsg                 :ARRAY[1..16] OF CHAR;
    ringMsg               :ARRAY[1..16] OF CHAR;
    nodialMsg             :ARRAY[1..16] OF CHAR;
    noanswMsg             :ARRAY[1..16] OF CHAR;
    voiceMsg              :ARRAY[1..16] OF CHAR;

    {Command strings}

    ModemAnswer           :ARRAY[1..41] OF CHAR;
    AnswerDelay           :BYTE;
    EscapeStr             :ARRAY[1..11] OF CHAR;
    OffHookStr            :ARRAY[1..11] OF CHAR;
    ReconnectStr          :ARRAY[1..11] OF CHAR;
    Init1                 :ARRAY[1..50] OF CHAR;
    Init2                 :ARRAY[1..50] OF CHAR;
    Init3                 :ARRAY[1..50] OF CHAR;
    Resetstr              :ARRAY[1..50] OF CHAR;
    Downstr               :ARRAY[1..50] OF CHAR;
    HangupStr             :ARRAY[1..11] OF CHAR;
    DialStr               :ARRAY[1..11] OF CHAR;
    Prefix                :ARRAY[1..31] OF CHAR;                {Always added}
    Postfix               :ARRAY[1..31] OF CHAR;             {Always appended}
  END;{OLDESTMODEMCFG;}

  OLDESTLINECFG           =RECORD
    Fingerprint           :ARRAY[1..5] OF CHAR;     {Must contain "JoHo<NUL>"}
    FileRevision          :WORD;                           {OLDESTLINECFG_REV}
    CRC1                  :LONGINT;  {CRC32 of LINECFG excluding 1st 11 bytes}
    Modem                 :OLDESTMODEMCFG;
    CRC2                  :LONGINT;                  {CRC-32 of all the above}
  END;{OLDESLINECFG}

{end of file "linecfg.inc"}
