/*
**  mailhist.h
**
**  Structures for .HIS files
**
**  Copyright 1991-1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                          FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __MAILHIST_H__
#define __MAILHIST_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  The first record in the .HIS files is not a valid history entry. It
**  contains the date/time when the .HIS file was last packed or when
**  it was created if it has never been packed. So if you're reading the
**  .HIS files for any reason, skip the first record and you'll be at the
**  first valid record.
**
**  Note that the two char[] fields are in Pascal fashion. The first byte is
**  the length byte. The actual string starts at [1] and the string is NOT
**  NUL terminated.
**
**  Note that the COST field will contain zero for inbound mail sessions as
**  well as any failed session negotiated using the script language.
*/
typedef struct _ctlFDMHistRec
    {
    unsigned short int  year,                                  /*1990 - xxxx*/
                        month,                                      /*1 - 12*/
                        day,                                        /*1 - 31*/
                        hour,                                       /*0 - 23*/
                        min,                                        /*0 - 59*/
                        sec,                                        /*0 - 59*/
                        zone,                        /*Remote system address*/
                        net,
                        node,
                        point;
    char                system_name[31];                /*Remote system name*/
    char                city[37];                   /*Remote system location*/
    unsigned char       Flags;             /*0x01=ReceivedEndOfBatchSignalOK*/
    unsigned char       task;                /*Task that added the entry (C)*/
    unsigned short int  timeonline;                  /*Seconds spent on-line*/
    unsigned long       rcvd_bytes,                   /*Total received bytes*/
                        sent_bytes;                       /*Total sent bytes*/
    unsigned short int  cost;                              /*Cost of session*/
    }
    ctlFDMHistRec;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "mailhist.h" */
