/*
**  nodelist.h
**
**  Structure for the FrontDoor Nodelist Database
**
**  Copyright 1993, 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                           FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __NODELIST_H__
#define __NODELIST_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  The FrontDoor Nodelist Database (FDND) uses a Pascal product from
**  Borland that has, unfortunately, been discontinued. It is called
**  "Turbo Database Toolkit" and works in a similar fashion to that of
**  many B+ filer toolkits.
**
**  This header file does not make an attempt to document the B+ file
**  structures, but only those fixed structures used by FrontDoor. For
**  owners of the Borland toolkit, the "TACCESS parameters" are listed
**  below.
**
**    NodeRecSize       = 178
**    FileHeaderSize    = 14
**    MinDataRecSize    = 14
**    MaxHeight         = 5
**    MaxDataRecSize    = 178
**    MaxKeyLen         = 24
**    PageSize          = 32
**    Order             = 16
**    PageStackSize     = 5
**    ItemOverhead      = 9
**    PageOverhead      = 5
*/

/*
**  NODEFILE.FDX contains some information about the Nodelist Database.
**
**  The information starts at offset 0x100 and is as follows:
**
**    Current nodelist extension          4 chars         (Pascal)
**    Nodelist Database revision         16 bit
**    Swedish pulse dial translation      1 byte
**
**  At offset 0x110, a set of the currently compiled zones is listed.
*/

/*
**  The private Nodelist Database (FDNODE.FDA) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/

  /* Status */

#define ISZC        1
#define ISRC        2
#define ISNC        3
#define ISHUB       4
#define ISPVT       5
#define ISHOLD      6
#define ISDOWN      7
#define ISPOINT     9

  /* Capability flags */

#define NLflagCM    0x00000001L                               /*"CM"    flag*/
#define NLflagMO    0x00000002L                               /*"MO"    flag*/
#define NLflagLO    0x00000004L                               /*"LO"    flag*/
#define NLflagMN    0x00000008L                               /*"MN"    flag*/
#define NLflagV32   0x00000010L                               /*"V32"   flag*/
#define NLflagV32B  0x00000020L                               /*"V32B"  flag*/
#define NLflagV42   0x00000040L                               /*"V42"   flag*/
#define NLflagV42B  0x00000080L                               /*"V42B"  flag*/
#define NLflagV34   0x00000100L                               /*"V34"   flag*/
#define NLflagZYX   0x00000400L                               /*"ZYX"   flag*/
#define NLflagHST   0x00000800L                               /*"HST"   flag*/
#define NLflagFAX   0x00001000L                               /*"FAX"   flag*/
#define NLflagX2C   0x00002000L                               /*"X2C"   flag*/
#define NLflagX2S   0x00004000L                               /*"X2S"   flag*/
#define NLflagXA    0x00020000L                               /*"XA"    flag*/
#define NLflagXB    0x00040000L                               /*"XB"    flag*/
#define NLflagXC    0x00080000L                               /*"XC"    flag*/
#define NLflagXP    0x00100000L                               /*"XP"    flag*/
#define NLflagXR    0x00200000L                               /*"XR"    flag*/
#define NLflagXW    0x00400000L                               /*"XW"    flag*/
#define NLflagXX    0x00800000L                               /*"XX"    flag*/
#define NLflagX75   0x01000000L                               /*"X75"   flag*/
#define NLflagV110L 0x02000000L                               /*"V110L" flag*/
#define NLflagV110H 0x04000000L                               /*"V110H" flag*/
#define NLflagV120L 0x08000000L                               /*"V120L" flag*/
#define NLflagV120H 0x10000000L                               /*"V120H" flag*/

  /* MaxBaud field */

#define ISBAUD300       1
#define ISBAUD1200      2
#define ISBAUD2400      3
#define ISBAUD4800      4
#define ISBAUD9600      5
#define ISBAUD12000     18
#define ISBAUD14400     6
#define ISBAUD16800     7
#define ISBAUD19200     8
#define ISBAUD21600     9
#define ISBAUD24000     19
#define ISBAUD28800     10
#define ISBAUD31200     20
#define ISBAUD33600     11
#define ISBAUD38400     12
#define ISBAUD57600     13
#define ISBAUD64000     14
#define ISBAUD76800     15
#define ISBAUD115200    16
#define ISBAUD128000    17
#define ISBAUD256000    21

  /* Record structure */

  /* Note that while the private database can only hold a fixed amount of
     information about a system's capabilities (nodelist flags), FrontDoor
     is capable of using the actual string present in FidoNet-style node-
     lists for routing and other lookup purposes. */

typedef struct _FDNodelistRec
    {
    long                  Erased;             /*Used to signal erased status*/
    unsigned char         Status;                    /*Zone, host, hub, etc.*/
    unsigned short int    NodeNo,                          /*Network address*/
                          NetNo,
                          Zone,
                          Point,
                          RoutNode,            /*Default routing within zone*/
                          RoutNet,     /*Contains region number for net host*/
                          Cost;                 /*Cost per minute for system*/
    long                  Capability;                     /*Capability flags*/
    unsigned char         MaxBaud;                       /*Maximum baud rate*/
    char                  Name[31];                         /*Name of system*/
    char                  Telephone[41];              /*Raw telephone number*/
    char                  Location[41];                 /*Location of system*/
    char                  User[37];                             /*SysOp name*/
    char                  SelectTag[4];                        /*Group field*/
    }
    FDNodelistRec;

/*
**  The telephone number database (FDPHONE.FDA) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef struct _FDPhoneRec
    {
    long                  Erased;             /*Used to signal erased status*/
    char                  Telephone[41];          /*Phone number translation*/
    unsigned short int    Cost;                   /*Cost per minute of calls*/
    unsigned short int    Baudrate;             /*Max baudrate for this area*/
    }
    FDPhoneRec;

/*
**  The nodelist index file (NODELIST.FDX) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef struct _FDNodelistIdxRec
    {
    unsigned char         Length;               /*Length byte for key string*/
    unsigned short int    Zone,                   /*Swapped zone for sorting*/
                          Net,                     /*Swapped net for sorting*/
                          Node,                   /*Swapped node for sorting*/
                          Point,                 /*Swapped point for sorting*/
                          RoutNet,             /*Default routing within zone*/
                          RoutNode;
    unsigned char         Status;                                /*See above*/
    unsigned char         RESERVED;                               /*Reserved*/
    }
    FDNodelistIdxRec;

/*
**  The userlist index file (USERLIST.FDX) has the following record
**  format. Note that the char[] fields are in Pascal fashion. The first
**  byte is the length byte. The actual string starts at [1] and the
**  string is NOT NUL terminated.
*/
typedef union _FDUserlistIdxRec
    {
    char                NameIt[37];             /*To facilitate use of moves*/
    struct
        {
        char            User[16];                   /*Actual name key length*/
        unsigned short int
                        Zone,                       /*To return address info*/
                        Net,
                        Node,
                        Point;
        unsigned char   Status;                     /*Node status, see above*/
        }
        NodeInfo;
    }
    FDUserlistIdxRec;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "nodelist.h" */

