(*
**  nodelist.inc
**
**  Structure for the FrontDoor Nodelist Database
**
**  Copyright 1993, 1997 Definite Solutions HB; All rights reserved.
**
**  Last revised: 97-11-21                           FrontDoor 2.25+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

(*
**  The FrontDoor Nodelist Database (FDND) uses a Pascal product from
**  Borland that has, unfortunately, been discontinued. It is called
**  "Turbo Database Toolkit" and works in a similar fashion to that of
**  many B+ filer toolkits.
**
**  This header file does not make an attempt to document the B+ file
**  structures, but only those fixed structures used by FrontDoor. For
**  owners of the Borland toolkit, the "TACCESS parameters" are listed
**  below.
**
**    NodeRecSize       = 178
**    FileHeaderSize    = 14
**    MinDataRecSize    = 14
**    MaxHeight         = 5
**    MaxDataRecSize    = 178
**    MaxKeyLen         = 24
**    PageSize          = 32
**    Order             = 16
**    PageStackSize     = 5
**    ItemOverhead      = 9
**    PageOverhead      = 5
*)

(*
**  NODEFILE.FDX contains some information about the Nodelist Database.
**
**  The information starts at offset 0x100 and is as follows:
**
**    Current nodelist extension          4 chars         (Pascal)
**    Nodelist Database revision         16 bit
**    Swedish pulse dial translation      1 byte
**
**  At offset 0x110, a set of the currently compiled zones is listed.
*)

(*
**  The private Nodelist Database (FDNODE.FDA) has the following record
**  format.
*)

  { Status }

CONST
  ISZC        =1;
  ISRC        =2;
  ISNC        =3;
  ISHUB       =4;
  ISPVT       =5;
  ISHOLD      =6;
  ISDOWN      =7;
  ISPOINT     =9;

  { Capability flags }

  NLflagCM    =$00000001;                                       {"CM"    flag}
  NLflagMO    =$00000002;                                       {"MO"    flag}
  NLflagLO    =$00000004;                                       {"LO"    flag}
  NLflagMN    =$00000008;                                       {"MN"    flag}
  NLflagV32   =$00000010;                                       {"V32"   flag}
  NLflagV32B  =$00000020;                                       {"V32B"  flag}
  NLflagV42   =$00000040;                                       {"V42"   flag}
  NLflagV42B  =$00000080;                                       {"V42B"  flag}
  NLflagV34   =$00000100;                                       {"V34"   flag}
  NLflagZYX   =$00000400;                                       {"ZYX"   flag}
  NLflagHST   =$00000800;                                       {"HST"   flag}
  NLflagFAX   =$00001000;                                       {"FAX"   flag}
  NLflagX2C   =$00002000;                                       {"X2C"   flag}
  NLflagX2S   =$00004000;                                       {"X2S"   flag}
  NLflagXA    =$00020000;                                       {"XA"    flag}
  NLflagXB    =$00040000;                                       {"XB"    flag}
  NLflagXC    =$00080000;                                       {"XC"    flag}
  NLflagXP    =$00100000;                                       {"XP"    flag}
  NLflagXR    =$00200000;                                       {"XR"    flag}
  NLflagXW    =$00400000;                                       {"XW"    flag}
  NLflagXX    =$00800000;                                       {"XX"    flag}
  NLflagX75   =$01000000;                                       {"X75"   flag}
  NLflagV110L =$02000000;                                       {"V110L" flag}
  NLflagV110H =$04000000;                                       {"V110H" flag}
  NLflagV120L =$08000000;                                       {"V120L" flag}
  NLflagV120H =$10000000;                                       {"V120H" flag}

  { MaxBaud field }

  ISBAUD300   =1
  ISBAUD1200  =2
  ISBAUD2400  =3
  ISBAUD4800  =4
  ISBAUD9600  =5
  ISBAUD12000 =18
  ISBAUD14400 =6
  ISBAUD16800 =7
  ISBAUD19200 =8
  ISBAUD21600 =9
  ISBAUD24000 =19
  ISBAUD28800 =10
  ISBAUD31200 =20
  ISBAUD33600 =11
  ISBAUD38400 =12
  ISBAUD57600 =13
  ISBAUD64000 =14
  ISBAUD76800 =15
  ISBAUD115200=16
  ISBAUD128000=17
  ISBAUD256000=21

  { Record structure }

  { Note that while the private database can only hold a fixed amount of
    information about a system's capabilities (nodelist flags), FrontDoor
    is capable of using the actual string present in FidoNet-style node-
    lists for routing and other lookup purposes. }

TYPE
  NODEREC = RECORD
    Erased            : LONGINT;                {Used to signal erased status}
    Status            : BYTE;                          {Zone, host, hub, etc.}
    NodeNo,                                                  {Network address}
    NetNo,
    Zone,
    Point,
    RoutNode,                                    {Default routing within zone}
    RoutNet,
    Cost              : WORD;                     {Cost per minute for system}
    Capability        : LONGINT;                            {Capability flags}
    MaxBaud           : BYTE;                              {Maximum baud rate}
    Name              : STRING[30];                           {Name of system}
    Telephone         : STRING[40];                     {Raw telephone number}
    Location          : STRING[40];                       {Location of system}
    User              : STRING[36];                               {SysOp name}
    SelectTag         : STRING[3];                               {Group field}
  END;{NODEREC}

(*
**  The telephone number database (FDPHONE.FDA) has the following record
**  format.
*)
  PHONEREC = RECORD
    Erase             : LONGINT;                {Used to signal erased status}
    Telephone         : STRING[40];                 {Phone number translation}
    Cost              : WORD;                       {Cost per minute of calls}
    Baudrate          : WORD;                     {Max baudrate for this area}
  END;{PHONEREC}

(*
**  The nodelist index file (NODELIST.FDX) has the following record
**  format.
*)
  NODEIDXREC = RECORD
    Length            : BYTE;                     {Length byte for key string}
    Zone,                                           {Swapped zone for sorting}
    Net,                                             {Swapped net for sorting}
    Node,                                           {Swapped node for sorting}
    Point,                                         {Swapped point for sorting}
    RoutNet,                                     {Default routing within zone}
    RoutNode          : WORD;
    Status            : BYTE;                                      {See above}
    RESERVED          : BYTE;                                       {Reserved}
  END;{NODEIDXREC}

(*
**  The userlist index file (USERLIST.FDX) has the following record
**  format.
*)
  USERIDXREC = RECORD CASE INTEGER OF
    1:  (NameIt       : STRING[36]);              {To facilitate use of moves}
    2:  (User         : STRING[15];                   {Actual name key length}
         Zone,                                        {To return address info}
         Net,
         Node,
         Point        : WORD;
         Status       : BYTE);                        {Node status, see above}
  END;{USERIDXREC}

(* end of file "nodelist.inc" *)

